PropertyChange

Enum PropertyChange 

#[non_exhaustive]
pub enum PropertyChange { Volume(Volume), Mute(Mute), Bass(Bass), Treble(Treble), Loudness(Loudness), PlaybackState(PlaybackState), Position(Position), CurrentTrack(CurrentTrack), GroupMembership(GroupMembership), GroupVolume(GroupVolume), GroupMute(GroupMute), GroupVolumeChangeable(GroupVolumeChangeable), }
A single property change

#[non_exhaustive] because this enum is public API (re-exported from sonos-sdk) and gains a variant every time a property is added. Without it, every consumer match would be exhaustive-by-default and adding a property would be a breaking change; consumers must include a _ => arm.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Volume(Volume)



Mute(Mute)



Bass(Bass)



Treble(Treble)



Loudness(Loudness)



PlaybackState(PlaybackState)



Position(Position)



CurrentTrack(CurrentTrack)



GroupMembership(GroupMembership)



GroupVolume(GroupVolume)



GroupMute(GroupMute)



GroupVolumeChangeable(GroupVolumeChangeable)

Implementations

Source

impl PropertyChange

pub fn apply( &self, store: &mut StateStore, speaker_id: &SpeakerId, stamp: WriteStamp, ) -> WriteOutcome

Apply this change to the store using scope-based routing

Speaker-scoped properties are stored in speaker_props, group-scoped properties resolve speaker→group and store in group_props.

Returns the WriteOutcomeChanged only if the value actually changed and stamp was not older than the stored observation.

pub fn key(&self) -> &'static str

Get the property key for this change

pub fn scope(&self) -> Scope

Get the scope of this property

pub fn service(&self) -> Service

Get the service this property belongs to